@@ -32,6 +32,7 @@ Usage::
         PasswordDataAvailableWaiter,
         SecurityGroupExistsWaiter,
         SnapshotCompletedWaiter,
+        SnapshotImportedWaiter,
         SpotInstanceRequestFulfilledWaiter,
         SubnetAvailableWaiter,
         SystemStatusOkWaiter,
@@ -71,6 +72,7 @@ Usage::
     password_data_available_waiter: PasswordDataAvailableWaiter = client.get_waiter("password_data_available")
     security_group_exists_waiter: SecurityGroupExistsWaiter = client.get_waiter("security_group_exists")
     snapshot_completed_waiter: SnapshotCompletedWaiter = client.get_waiter("snapshot_completed")
+    snapshot_imported_waiter: SnapshotImportedWaiter = client.get_waiter("snapshot_imported")
     spot_instance_request_fulfilled_waiter: SpotInstanceRequestFulfilledWaiter = client.get_waiter("spot_instance_request_fulfilled")
     subnet_available_waiter: SubnetAvailableWaiter = client.get_waiter("subnet_available")
     system_status_ok_waiter: SystemStatusOkWaiter = client.get_waiter("system_status_ok")
@@ -114,6 +116,7 @@ __all__ = (
     "PasswordDataAvailableWaiter",
     "SecurityGroupExistsWaiter",
     "SnapshotCompletedWaiter",
+    "SnapshotImportedWaiter",
     "SpotInstanceRequestFulfilledWaiter",
     "SubnetAvailableWaiter",
     "SystemStatusOkWaiter",
@@ -597,6 +600,28 @@ class SnapshotCompletedWaiter(Waiter):
         """
 
 
+class SnapshotImportedWaiter(Waiter):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SnapshotImported)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#snapshotimportedwaiter)
+    """
+
+    def wait(
+        self,
+        *,
+        DryRun: bool = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
+        ImportTaskIds: Sequence[str] = ...,
+        MaxResults: int = ...,
+        NextToken: str = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
+    ) -> None:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SnapshotImported.wait)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters/#snapshotimportedwaiter)
+        """
+
+
 class SpotInstanceRequestFulfilledWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2.Waiter.SpotInstanceRequestFulfilled)
